/* $Id: generate_defs_gda.cc,v 1.9 2005/09/22 06:39:23 murrayc Exp $ */

/* generate_defs_gda.h
 *
 * Copyright 2006-2008 The maemomm development team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "glibmm_generate_extra_defs/generate_extra_defs.h"

#include <hildon/hildon-file-chooser-dialog.h>
#include <hildon/hildon-file-details-dialog.h>
#include <hildon/hildon-file-selection.h>
#include <hildon/hildon-file-system-model.h>

#include <gtk/gtk.h>


int main (int argc, char *argv[])
{
    gtk_init(&argc, &argv);

    std::cout << get_defs(HILDON_TYPE_FILE_CHOOSER_DIALOG)
              << get_defs(HILDON_TYPE_FILE_DETAILS_DIALOG)
              << get_defs(HILDON_TYPE_FILE_SELECTION)
              << get_defs(HILDON_TYPE_FILE_SYSTEM_MODEL)
              << std::endl;

    return 0;
}
